@@ -1,4 +1,4 @@
-# $Id: Document.pm 32558 2010-09-23 13:27:12Z wsl $
+# $Id: Document.pm 33755 2011-02-03 14:26:34Z wsl $
 # $URL: https://infix.uvt.nl/its-id/trunk/sources/loandesk/lib/UvT/Loandesk/Document.pm $
 
 use utf8;
@@ -25,7 +25,6 @@ sub dumpreq {
 	while($req) {
 		my $c = eval { $req->organizationcookie };
 		$c = defined $c ? "'$c'" : 'undef';
-		warn "organizationcookie=$c ($req)";
 		$req = eval { $req->ctx };
 	}
 }
@@ -48,7 +47,6 @@ sub response {
 		$res->setcookie($cookie);
 	}
 	if(my $authbroker = $req->authbrokercookie) {
-		warn "Set-Cookie: authbroker=$authbroker";
 		my $cookie = $self->bakecookie(authbroker => $authbroker);
 		$res->setcookie($cookie);
 	}
