@@ -1,4 +1,4 @@
-# $Id: SendRequest.pm 33254 2010-12-06 16:42:02Z wsl $
+# $Id: SendRequest.pm 33784 2011-02-07 08:06:16Z wsl $
 # $URL: https://infix.uvt.nl/its-id/trunk/sources/loandesk/lib/UvT/Loandesk/SendRequest.pm $
 
 use utf8;
@@ -25,11 +25,28 @@ sub build {
 		warn $@ if $@;
 	}
 
-	if(my ($frag) = eval { $self->getFragment(mps => $req->mnemonic) }) {
-		$feedback->replaceNode($frag);
+	if(my $returndate = $req->returndate) {
+		my ($frag, $ids) = $self->getFragment(returndate => 'havedate');
+		$ids->{returndate}->appendText($returndate);
+		my $el = $self->getElementById('returndate');
+		$el->replaceNode($frag);
 	} else {
-		warn $@ if $@;
-		$feedback->appendText($req->message);
+		my ($frag) = $self->getFragment(returndate => 'nodate');
+		my $el = $self->getElementById('returndate');
+		$el->replaceNode($frag);
+	}
+
+	my $message = $req->message;
+	my $mnemonic = $req->mnemonic;
+	eval {
+		die "No mnemonic found in MPS response ($message)\n" unless $mnemonic;
+		my ($frag) = $self->getFragment(mps => $req->mnemonic);
+		$feedback->replaceNode($frag);
+	};
+	if(my $err = $@) {
+		$err =~ s/\n.*//;
+		warn "Unable to load text for mnemonic: $err\n";
+		$feedback->appendText($message);
 	}
 }
 
